@@ -10,6 +10,8 @@ index((aggregate_all), 3, aggregate, aggregate).
 index((aggregate_all), 4, aggregate, aggregate).
 index((free_variables), 4, aggregate, aggregate).
 index((ansi_format), 3, ansi_term, ansi_term).
+index((expand_phrase), 2, apply_macros, apply_macros).
+index((expand_phrase), 4, apply_macros, apply_macros).
 index((include), 3, apply, apply).
 index((exclude), 3, apply, apply).
 index((partition), 4, apply, apply).
@@ -27,8 +29,6 @@ index((scanl), 4, apply, apply).
 index((scanl), 5, apply, apply).
 index((scanl), 6, apply, apply).
 index((scanl), 7, apply, apply).
-index((expand_phrase), 2, apply_macros, apply_macros).
-index((expand_phrase), 4, apply_macros, apply_macros).
 index((archive_open), 3, archive, archive).
 index((archive_open), 4, archive, archive).
 index((archive_create), 3, archive, archive).
@@ -41,6 +41,7 @@ index((archive_set_header_property), 2, archive, archive).
 index((archive_extract), 3, archive, archive).
 index((archive_entries), 2, archive, archive).
 index((archive_data_stream), 3, archive, archive).
+index((archive_foldl), 4, archive, archive).
 index((arithmetic_function), 1, arithmetic, arithmetic).
 index((arithmetic_expression_value), 2, arithmetic, arithmetic).
 index((empty_assoc), 1, assoc, assoc).
@@ -170,6 +171,11 @@ index((open_chars_stream), 2, charsio, charsio).
 index((with_output_to_chars), 2, charsio, charsio).
 index((with_output_to_chars), 3, charsio, charsio).
 index((with_output_to_chars), 4, charsio, charsio).
+index((check_installation), 0, check_installation, check_installation).
+index((check_installation), 1, check_installation, check_installation).
+index((test_installation), 0, check_installation, check_installation).
+index((test_installation), 1, check_installation, check_installation).
+index((check_old_last), 0, checklast, checklast).
 index((check), 0, check, check).
 index((list_undefined), 0, check, check).
 index((list_undefined), 1, check, check).
@@ -180,11 +186,6 @@ index((list_trivial_fails), 0, check, check).
 index((list_trivial_fails), 1, check, check).
 index((list_strings), 0, check, check).
 index((list_strings), 1, check, check).
-index((check_installation), 0, check_installation, check_installation).
-index((check_installation), 1, check_installation, check_installation).
-index((test_installation), 0, check_installation, check_installation).
-index((test_installation), 1, check_installation, check_installation).
-index((check_old_last), 0, checklast, checklast).
 index((check_old_select), 0, checkselect, checkselect).
 index((format_to_codes), 3, codesio, codesio).
 index((format_to_codes), 4, codesio, codesio).
@@ -199,7 +200,6 @@ index((with_output_to_codes), 2, codesio, codesio).
 index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
-index((crypt), 2, crypt, crypt).
 index((crypto_n_random_bytes), 2, crypto, crypto).
 index((crypto_data_hash), 3, crypto, crypto).
 index((crypto_file_hash), 3, crypto, crypto).
@@ -229,6 +229,7 @@ index((crypto_name_curve), 2, crypto, crypto).
 index((crypto_curve_order), 2, crypto, crypto).
 index((crypto_curve_generator), 2, crypto, crypto).
 index((crypto_curve_scalar_mult), 4, crypto, crypto).
+index((crypt), 2, crypt, crypt).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
@@ -312,6 +313,22 @@ index((reconsult), 1, edinburgh, edinburgh).
 index((debug), 0, edinburgh, edinburgh).
 index((nodebug), 0, edinburgh, edinburgh).
 index((fileerrors), 2, edinburgh, edinburgh).
+index((el_wrap), 0, editline, editline).
+index((el_wrap), 4, editline, editline).
+index((el_wrapped), 1, editline, editline).
+index((el_unwrap), 1, editline, editline).
+index((el_source), 2, editline, editline).
+index((el_bind), 2, editline, editline).
+index((el_addfn), 4, editline, editline).
+index((el_cursor), 2, editline, editline).
+index((el_line), 2, editline, editline).
+index((el_insertstr), 2, editline, editline).
+index((el_deletestr), 2, editline, editline).
+index((el_history), 2, editline, editline).
+index((el_history_events), 2, editline, editline).
+index((el_add_history), 2, editline, editline).
+index((el_write_history), 2, editline, editline).
+index((el_read_history), 2, editline, editline).
 index((edit), 1, prolog_edit, edit).
 index((edit), 0, prolog_edit, edit).
 index((type_error), 2, error, error).
@@ -334,8 +351,6 @@ index((fast_write), 1, fastrw, fastrw).
 index((fast_read), 2, fastrw, fastrw).
 index((fast_write), 2, fastrw, fastrw).
 index((fast_write_to_string), 3, fastrw, fastrw).
-index((can_open_file), 2, files, files).
-index((chdir), 1, files, files).
 index((set_time_file), 3, files_ex, filesex).
 index((link_file), 3, files_ex, filesex).
 index((chmod), 2, files_ex, filesex).
@@ -347,6 +362,8 @@ index((make_directory_path), 1, files_ex, filesex).
 index((copy_directory), 2, files_ex, filesex).
 index((delete_directory_and_contents), 1, files_ex, filesex).
 index((delete_directory_contents), 1, files_ex, filesex).
+index((can_open_file), 2, files, files).
+index((chdir), 1, files, files).
 index((reset_gensym), 0, gensym, gensym).
 index((reset_gensym), 1, gensym, gensym).
 index((gensym), 2, gensym, gensym).
@@ -391,6 +408,54 @@ index((iso_639_2), 2, iso_639, iso_639).
 index((iso_639_3), 2, iso_639, iso_639).
 index((iso_639), 2, iso_639, iso_639).
 index((isub), 4, isub, isub).
+index((jpl_get_default_jvm_opts), 1, jpl, jpl).
+index((jpl_set_default_jvm_opts), 1, jpl, jpl).
+index((jpl_get_actual_jvm_opts), 1, jpl, jpl).
+index((jpl_pl_lib_version), 1, jpl, jpl).
+index((jpl_c_lib_version), 1, jpl, jpl).
+index((jpl_pl_syntax), 1, jpl, jpl).
+index((jpl_new), 3, jpl, jpl).
+index((jpl_call), 4, jpl, jpl).
+index((jpl_get), 3, jpl, jpl).
+index((jpl_set), 3, jpl, jpl).
+index((jpl_servlet_byref), 3, jpl, jpl).
+index((jpl_servlet_byval), 3, jpl, jpl).
+index((jpl_class_to_classname), 2, jpl, jpl).
+index((jpl_class_to_type), 2, jpl, jpl).
+index((jpl_classname_to_class), 2, jpl, jpl).
+index((jpl_classname_to_type), 2, jpl, jpl).
+index((jpl_datum_to_type), 2, jpl, jpl).
+index((jpl_false), 1, jpl, jpl).
+index((jpl_is_class), 1, jpl, jpl).
+index((jpl_is_false), 1, jpl, jpl).
+index((jpl_is_null), 1, jpl, jpl).
+index((jpl_is_object), 1, jpl, jpl).
+index((jpl_is_object_type), 1, jpl, jpl).
+index((jpl_is_ref), 1, jpl, jpl).
+index((jpl_is_true), 1, jpl, jpl).
+index((jpl_is_type), 1, jpl, jpl).
+index((jpl_is_void), 1, jpl, jpl).
+index((jpl_null), 1, jpl, jpl).
+index((jpl_object_to_class), 2, jpl, jpl).
+index((jpl_object_to_type), 2, jpl, jpl).
+index((jpl_primitive_type), 1, jpl, jpl).
+index((jpl_ref_to_type), 2, jpl, jpl).
+index((jpl_true), 1, jpl, jpl).
+index((jpl_type_to_class), 2, jpl, jpl).
+index((jpl_type_to_classname), 2, jpl, jpl).
+index((jpl_void), 1, jpl, jpl).
+index((jpl_array_to_length), 2, jpl, jpl).
+index((jpl_array_to_list), 2, jpl, jpl).
+index((jpl_datums_to_array), 2, jpl, jpl).
+index((jpl_enumeration_element), 2, jpl, jpl).
+index((jpl_enumeration_to_list), 2, jpl, jpl).
+index((jpl_hashtable_pair), 2, jpl, jpl).
+index((jpl_iterator_element), 2, jpl, jpl).
+index((jpl_list_to_array), 2, jpl, jpl).
+index((jpl_terms_to_array), 2, jpl, jpl).
+index((jpl_array_to_terms), 2, jpl, jpl).
+index((jpl_map_element), 2, jpl, jpl).
+index((jpl_set_element), 2, jpl, jpl).
 index((lazy_list), 2, lazy_lists, lazy_lists).
 index((lazy_list), 3, lazy_lists, lazy_lists).
 index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
@@ -848,16 +913,16 @@ index((ord_list_to_rbtree), 2, rbtrees, rbtrees).
 index((is_rbtree), 1, rbtrees, rbtrees).
 index((rb_size), 2, rbtrees, rbtrees).
 index((rb_in), 3, rbtrees, rbtrees).
-index((load_rdf), 2, rdf, rdf).
-index((load_rdf), 3, rdf, rdf).
-index((xml_to_rdf), 3, rdf, rdf).
-index((process_rdf), 3, rdf, rdf).
 index((rdf_diagram_from_file), 1, rdf_diagram, rdf_diagram).
 index((xml_to_plrdf), 3, rdf_parser, rdf_parser).
 index((element_to_plrdf), 3, rdf_parser, rdf_parser).
 index((make_rdf_state), 3, rdf_parser, rdf_parser).
 index((rdf_modify_state), 3, rdf_parser, rdf_parser).
 index((rdf_name_space), 1, rdf_parser, rdf_parser).
+index((load_rdf), 2, rdf, rdf).
+index((load_rdf), 3, rdf, rdf).
+index((xml_to_rdf), 3, rdf, rdf).
+index((process_rdf), 3, rdf, rdf).
 index((rdf_triples), 2, rdf_triple, rdf_triple).
 index((rdf_triples), 3, rdf_triple, rdf_triple).
 index((rdf_reset_ids), 0, rdf_triple, rdf_triple).
@@ -1240,6 +1305,9 @@ index((/), 9, yall, yall).
 index((lambda_calls), 2, yall, yall).
 index((lambda_calls), 3, yall, yall).
 index((is_lambda), 1, yall, yall).
+index((yaml_read), 2, yaml, yaml).
+index((yaml_write), 2, yaml, yaml).
+index((yaml_write), 3, yaml, yaml).
 index((zip_open), 4, zip, zip).
 index((zip_close), 1, zip, zip).
 index((zip_close), 2, zip, zip).
